@@ -8,7 +8,7 @@ see the Wikipedia article on the clique problem [1]_.
 
 """
 
-from collections import defaultdict, deque
+from collections import Counter, defaultdict, deque
 from itertools import chain, combinations, islice
 
 import networkx as nx
@@ -156,7 +156,10 @@ def find_cliques(G, nodes=None):
     node. The following produces a dictionary keyed by node whose
     values are the number of maximal cliques in `G` that contain the node:
 
-    >>> pprint({n: sum(1 for c in nx.find_cliques(G) if n in c) for n in G})
+    >>> from collections import Counter
+    >>> from itertools import chain
+    >>> counts = Counter(chain.from_iterable(nx.find_cliques(G)))
+    >>> pprint(dict(counts))
     {0: 13,
      1: 6,
      2: 7,
@@ -294,7 +297,7 @@ def find_cliques(G, nodes=None):
         pass
 
 
-# TODO Should this also be not implemented for directed graphs?
+@not_implemented_for("directed")
 @nx._dispatchable
 def find_cliques_recursive(G, nodes=None):
     """Returns all maximal cliques in a graph.
@@ -315,6 +318,7 @@ def find_cliques_recursive(G, nodes=None):
     Parameters
     ----------
     G : NetworkX graph
+        An undirected graph.
 
     nodes : list, optional (default=None)
         If provided, only yield *maximal cliques* containing all nodes in `nodes`.
@@ -330,6 +334,9 @@ def find_cliques_recursive(G, nodes=None):
 
     Raises
     ------
+    NetworkXNotImplemented
+        If `G` is directed.
+
     ValueError
         If `nodes` is not a clique.
 
@@ -542,6 +549,7 @@ def node_clique_number(G, nodes=None, cliques=None, separate_nodes=False):
         It accepts a `nodes` argument which restricts consideration to
         maximal cliques containing all the given `nodes`.
         The search for the cliques is optimized for `nodes`.
+    number_of_cliques
     """
     if cliques is None:
         if nodes is not None:
@@ -575,13 +583,69 @@ def node_clique_number(G, nodes=None, cliques=None, separate_nodes=False):
 
 
 def number_of_cliques(G, nodes=None, cliques=None):
-    """Returns the number of maximal cliques for each node.
+    """Return the number of maximal cliques each node is part of.
 
-    Returns a single or list depending on input nodes.
+    Output is a single value or dict depending on `nodes`.
     Optional list of cliques can be input if already computed.
+
+    Parameters
+    ----------
+    G : NetworkX graph
+        An undirected graph.
+
+    nodes : list or None, optional (default=None)
+        A list of nodes to return the number of maximal cliques for.
+        If `None`, return the number of maximal cliques for all nodes.
+
+    cliques : list or None, optional (default=None)
+        A precomputed list of maximal cliques to use for the calculation.
+
+    Returns
+    -------
+    int or dict
+        If `nodes` is a single node, return the number of maximal cliques it is
+        part of. If `nodes` is a list, return a dictionary keyed by node to the
+        number of maximal cliques it is part of.
+
+    Raises
+    ------
+    NetworkXNotImplemented
+        If `G` is directed.
+
+    See Also
+    --------
+    find_cliques
+    node_clique_number
+
+    Examples
+    --------
+    Compute the number of maximal cliques a node is part of:
+
+    >>> G = nx.complete_graph(3)
+    >>> nx.add_cycle(G, [0, 3, 4])
+    >>> nx.number_of_cliques(G, nodes=0)
+    2
+    >>> nx.number_of_cliques(G, nodes=1)
+    1
+
+    Or, for a list of nodes:
+
+    >>> nx.number_of_cliques(G, nodes=[0, 1])
+    {0: 2, 1: 1}
+
+    If no explicit `nodes` are provided, all nodes are considered:
+
+    >>> nx.number_of_cliques(G)
+    {0: 2, 1: 1, 2: 1, 3: 1, 4: 1}
+
+    The list of maximal cliques can also be precomputed:
+
+    >>> cl = list(nx.find_cliques(G))
+    >>> nx.number_of_cliques(G, cliques=cl)
+    {0: 2, 1: 1, 2: 1, 3: 1, 4: 1}
     """
     if cliques is None:
-        cliques = list(find_cliques(G))
+        cliques = find_cliques(G)
 
     if nodes is None:
         nodes = list(G.nodes())  # none, get entire graph
@@ -589,11 +653,10 @@ def number_of_cliques(G, nodes=None, cliques=None):
     if not isinstance(nodes, list):  # check for a list
         v = nodes
         # assume it is a single value
-        numcliq = len([1 for c in cliques if v in c])
+        numcliq = sum(1 for c in cliques if v in c)
     else:
-        numcliq = {}
-        for v in nodes:
-            numcliq[v] = len([1 for c in cliques if v in c])
+        numcliq = Counter(chain.from_iterable(cliques))
+        numcliq = {v: numcliq[v] for v in nodes}  # return a dict
     return numcliq
 
 
